@@ -152,8 +152,8 @@ class LoadMaster(HttpClient):
     @property
     def endpoint(self):
         return "https://{user}:{pw}@{ip}/access".format(user=self.username,
-                                                         pw=self.password,
-                                                         ip=self.ip_address)
+                                                        pw=self.password,
+                                                        ip=self.ip_address)
 
     def set_parameter(self, parameter, value):
         parameters = {
@@ -222,7 +222,8 @@ class LoadMaster(HttpClient):
             if ApiXmlHelper.is_successful(response):
                 return ApiXmlHelper.parse_to_dict(response)
             else:
-                raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+                raise KempTechApiException(ApiXmlHelper.get_error_msg(
+                    response))
         except KempTechApiException:
             raise CommandNotAvailableException('/access360/licenseinfo')
 
